@@ -14,10 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -269,15 +267,9 @@ window_dispose (GObject *object)
 		priv->personal_details_window = NULL;
 	}
 
-	if (priv->git) {
-		g_object_unref (priv->git);
-		priv->git = NULL;
-	}
+	g_clear_object (&priv->git);
 
-	if (priv->recent_manager) {
-		g_object_unref (priv->recent_manager);
-		priv->recent_manager = NULL;
-	}
+        g_clear_object (&priv->recent_manager);
 
 	if (priv->recent_action_group) {
 		gtk_ui_manager_remove_action_group (priv->ui_manager,
@@ -285,20 +277,11 @@ window_dispose (GObject *object)
 		priv->recent_action_group = NULL;
 	}
 
-	if (priv->ui_manager) {
-		g_object_unref (priv->ui_manager);
-		priv->ui_manager = NULL;
-	}
+	g_clear_object (&priv->ui_manager);
 
-	if (priv->configuration) {
-		g_object_unref (priv->configuration);
-		priv->configuration = NULL;
-	}
+	g_clear_object (&priv->configuration);
 
-	if (priv->plugin_manager) {
-		g_object_unref (priv->plugin_manager);
-		priv->plugin_manager = NULL;
-	}
+	g_clear_object (&priv->plugin_manager);
 
 	G_OBJECT_CLASS (giggle_window_parent_class)->dispose (object);
 }
@@ -900,7 +883,7 @@ static void
 window_action_help_index_cb (GtkAction    *action,
                              GiggleWindow *window)
 {
-	window_visit_uri (window, "ghelp:" PACKAGE_TARNAME);
+	window_visit_uri (window, "help:" PACKAGE_TARNAME);
 }
 
 static void
@@ -941,7 +924,7 @@ window_action_about_cb (GtkAction    *action,
 
 	const gchar *copyright = _("Copyright © 2007 - 2008 Imendio AB\n"
 	                           "Copyright © 2008 - 2009 Mathias Hasselmann\n"
-	                           "Copyright © 2009 - 2011 The Giggle authors");
+	                           "Copyright © 2009 - 2012 The Giggle authors");
 
 	/* Translators: This is a special message that shouldn't be translated
          * literally. It is used in the about box to give credits to
@@ -1414,8 +1397,7 @@ window_recent_repositories_update (GiggleWindow *window)
 		}
 	}
 
-	g_list_foreach (recent_items, (GFunc) gtk_recent_info_unref, NULL);
-	g_list_free (recent_items);
+	g_list_free_full (recent_items, (GDestroyNotify) gtk_recent_info_unref);
 }
 
 static void
